@@ -17,6 +17,6 @@ fn setup(
         mesh: meshes.add(Mesh::from(shape::Quad::default())).into(),
         transform: Transform::default().with_scale(Vec3::splat(128.)),
         material: materials.add(ColorMaterial::from(Color::PURPLE)),
-        ..Default::default()
+        ..default()
     });
 }
