@@ -9,7 +9,7 @@ fn my_runner(mut app: App) {
     println!("Type stuff into the console");
     for line in io::stdin().lock().lines() {
         {
-            let mut input = app.world.get_resource_mut::<Input>().unwrap();
+            let mut input = app.world.resource_mut::<Input>();
             input.0 = line.unwrap();
         }
         app.update();
