@@ -6,9 +6,11 @@ fn main() {
     App::new()
         .add_plugins(DefaultPlugins)
         .add_event::<MyEvent>()
+        .add_event::<PlaySound>()
         .init_resource::<EventTriggerState>()
-        .add_system(event_trigger_system)
-        .add_system(event_listener_system)
+        .add_system(event_trigger)
+        .add_system(event_listener)
+        .add_system(sound_player)
         .run();
 }
 
@@ -16,6 +18,9 @@ struct MyEvent {
     pub message: String,
 }
 
+#[derive(Default)]
+struct PlaySound;
+
 struct EventTriggerState {
     event_timer: Timer,
 }
@@ -28,22 +33,30 @@ impl Default for EventTriggerState {
     }
 }
 
-// sends MyEvent every second
-fn event_trigger_system(
+// sends MyEvent and PlaySound every second
+fn event_trigger(
     time: Res<Time>,
     mut state: ResMut<EventTriggerState>,
     mut my_events: EventWriter<MyEvent>,
+    mut play_sound_events: EventWriter<PlaySound>,
 ) {
     if state.event_timer.tick(time.delta()).finished() {
         my_events.send(MyEvent {
             message: "MyEvent just happened!".to_string(),
         });
+        play_sound_events.send_default();
     }
 }
 
 // prints events as they come in
-fn event_listener_system(mut events: EventReader<MyEvent>) {
+fn event_listener(mut events: EventReader<MyEvent>) {
     for my_event in events.iter() {
         info!("{}", my_event.message);
     }
 }
+
+fn sound_player(mut play_sound_events: EventReader<PlaySound>) {
+    for _ in play_sound_events.iter() {
+        info!("Playing a sound");
+    }
+}
