@@ -11,7 +11,7 @@ fn main() {
             transparent: true,
             // Disabling window decorations to make it feel more like a widget than a window
             decorations: false,
-            ..Default::default()
+            ..default()
         })
         .add_startup_system(setup)
         .add_plugins(DefaultPlugins)
@@ -22,6 +22,6 @@ fn setup(mut commands: Commands, asset_server: Res<AssetServer>) {
     commands.spawn_bundle(OrthographicCameraBundle::new_2d());
     commands.spawn_bundle(SpriteBundle {
         texture: asset_server.load("branding/icon.png"),
-        ..Default::default()
+        ..default()
     });
 }
